##############
ItemSize class
##############

.. currentmodule:: ddbmock.database.item

.. autoclass:: ItemSize

ItemSize manipulations
======================

__add__
-------

.. automethod:: ItemSize.__add__

as_units
--------

.. automethod:: ItemSize.as_units

with_indexing_overhead
----------------------

.. automethod:: ItemSize.with_indexing_overhead

